@@ -120,9 +120,6 @@ sub public {
         };
     };
 
-use Data::Dumper;
-print Dumper $struct;
-
     return Crypt::Perl::ECDSA::PublicKey->new(
         $struct->{'publicKey'}[0],
         $struct->{'keydata'}{'parameters'},
